Structs
- Command
Builder CommandBuilderis used to prepare a command to be spawned into a pty. The interface is intentionally similar to that ofstd::process::Command.
CommandBuilder is used to prepare a command to be spawned into a pty.
The interface is intentionally similar to that of std::process::Command.